@@ -26,7 +26,8 @@ __version__ = "$Id: action.py 312 2007-04-09 19:45:49Z wrobel $"
 
 import os, sys
 
-from   layman.db                import DB, RemoteDB, UnknownOverlayException
+from   layman.dbbase            import UnknownOverlayException, BrokenOverlayCatalog
+from   layman.db                import DB, RemoteDB
 from   layman.utils             import path, delete_empty_directory
 from   layman.debug             import OUT
 
@@ -65,7 +66,7 @@ class Fetch:
     '''
 
     def __init__(self, config):
-        self.db = RemoteDB(config)
+        self.db = RemoteDB(config, ignore_init_read_errors=True)
 
     def run(self):
         '''Fetch the overlay listing.'''
@@ -96,8 +97,8 @@ class Sync:
 
         self.selection = config['sync']
 
-	if config['sync_all'] or 'ALL' in self.selection:
-	    self.selection = self.db.overlays.keys()
+        if config['sync_all'] or 'ALL' in self.selection:
+            self.selection = self.db.overlays.keys()
 
         enc = sys.getfilesystemencoding()
         if enc:
@@ -498,11 +499,11 @@ class ListLocal:
 
 #===============================================================================
 #
-# Class Actions
+# MAIN
 #
 #-------------------------------------------------------------------------------
 
-class Actions:
+def main(config):
     '''Dispatches to the actions the user selected. '''
 
     # Given in order of precedence
@@ -515,7 +516,7 @@ class Actions:
                ('list',       List),
                ('list_local', ListLocal),]
 
-    def __init__(self, config):
+    if True:  # A hack to save diff with indentation changes only
 
         # Make fetching the overlay list a default action
         if not 'nofetch' in config.keys():
@@ -538,12 +539,17 @@ class Actions:
             OUT.die('Failed setting to umask "' + umask + '"!\nError was: ' 
                     + str(error))
 
-        for i in self.actions:
+        for i in actions:
 
             OUT.debug('Checking for action', 7)
 
             if i[0] in config.keys():
-                result += i[1](config).run()
+                try:
+                    result += i[1](config).run()
+                except Exception, error:
+                    OUT.error(str(error))
+                    result = -1  # So it cannot remain 0, i.e. success
+                    break
 
         # Reset umask
         os.umask(old_umask)
@@ -552,7 +558,7 @@ class Actions:
             sys.exit(0)
         else:
             sys.exit(1)
-            
+
 #===============================================================================
 #
 # Testing
@@ -560,7 +566,7 @@ class Actions:
 #-------------------------------------------------------------------------------
 
 if __name__ == '__main__':
-    import doctest, sys
+    import doctest
 
     # Ignore warnings here. We are just testing
     from warnings     import filterwarnings, resetwarnings
