@@ -27,7 +27,7 @@ __version__ = "$Id: bzr.py 236 2006-09-05 20:39:37Z wrobel $"
 #-------------------------------------------------------------------------------
 
 from   layman.utils             import path
-from   layman.overlays.overlay  import Overlay
+from   layman.overlays.source   import OverlaySource, require_supported
 
 #===============================================================================
 #
@@ -35,15 +35,15 @@ from   layman.overlays.overlay  import Overlay
 #
 #-------------------------------------------------------------------------------
 
-class BzrOverlay(Overlay):
+class BzrOverlay(OverlaySource):
     ''' Handles bzr overlays.'''
 
     type = 'Bzr'
     type_key = 'bzr'
 
-    def __init__(self, xml, config, ignore = 0, quiet = False):
+    def __init__(self, parent, xml, config, _location, ignore = 0, quiet = False):
 
-        Overlay.__init__(self, xml, config, ignore)
+        super(BzrOverlay, self).__init__(parent, xml, config, _location, ignore, quiet)
 
     def add(self, base, quiet = False):
         '''Add overlay.'''
@@ -51,19 +51,19 @@ class BzrOverlay(Overlay):
         self.supported()
 
         return self.cmd(self.command() + ' get "' + self.src + '/" "' +\
-                        path([base, self.name]) + '"')
+                        path([base, self.parent.name]) + '"')
 
     def sync(self, base, quiet = False):
         '''Sync overlay.'''
 
         self.supported()
 
-        return self.cmd('cd "' + path([base, self.name]) + '" && ' +          \
+        return self.cmd('cd "' + path([base, self.parent.name]) + '" && ' +          \
                         self.command() + ' pull --overwrite "' + self.src \
                         + '"')
 
     def supported(self):
         '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.command(),  'bzr',
+        return require_supported([(self.command(),  'bzr',
                                          'dev-util/bzr'),])
