@@ -27,7 +27,7 @@ __version__ = "$Id$"
 import xml.etree.ElementTree as ET # Python 2.5
 
 from   layman.utils             import path, ensure_unicode
-from   layman.overlays.source   import OverlaySource
+from   layman.overlays.source   import OverlaySource, require_supported
 
 #===============================================================================
 #
@@ -99,5 +99,5 @@ class CvsOverlay(OverlaySource):
     def supported(self):
         '''Overlay type supported?'''
 
-        return super(CvsOverlay, self).supported([(self.command(),  'cvs',
+        return require_supported([(self.command(),  'cvs',
                                          'dev-util/cvs'),])
