@@ -26,7 +26,7 @@ __version__ = "$Id: darcs.py 236 2006-09-05 20:39:37Z wrobel $"
 #-------------------------------------------------------------------------------
 
 from   layman.utils             import path
-from   layman.overlays.overlay  import Overlay
+from   layman.overlays.source   import OverlaySource, require_supported
 
 #===============================================================================
 #
@@ -34,15 +34,15 @@ from   layman.overlays.overlay  import Overlay
 #
 #-------------------------------------------------------------------------------
 
-class DarcsOverlay(Overlay):
+class DarcsOverlay(OverlaySource):
     ''' Handles darcs overlays.'''
 
     type = 'Darcs'
     type_key = 'darcs'
 
-    def __init__(self, xml, config, ignore = 0, quiet = False):
+    def __init__(self, parent, xml, config, _location, ignore = 0, quiet = False):
 
-        Overlay.__init__(self, xml, config, ignore)
+        super(DarcsOverlay, self).__init__(parent, xml, config, _location, ignore, quiet)
 
     def add(self, base, quiet = False):
         '''Add overlay.'''
@@ -50,18 +50,18 @@ class DarcsOverlay(Overlay):
         self.supported()
 
         return self.cmd(self.command() + ' get --partial "' + self.src +
-                        '/" "' + path([base, self.name]) + '"')
+                        '/" "' + path([base, self.parent.name]) + '"')
 
     def sync(self, base, quiet = False):
         '''Sync overlay.'''
 
         self.supported()
 
-        return self.cmd('cd "' + path([base, self.name]) + '" && ' +
+        return self.cmd('cd "' + path([base, self.parent.name]) + '" && ' +
                         self.command() + ' pull --all "' + self.src + '"')
 
     def supported(self):
         '''Overlay type supported?'''
 
-        return Overlay.supported(self, [(self.command(),  'darcs',
+        return require_supported([(self.command(),  'darcs',
                                          'dev-util/darcs'),])
