@@ -33,7 +33,7 @@ import codecs
 import locale
 import xml.etree.ElementTree as ET # Python 2.5
 
-from   layman.utils             import path, ensure_unicode
+from   layman.utils             import ensure_unicode
 
 from   layman.debug             import OUT
 
@@ -112,10 +112,10 @@ class Overlay(object):
         if _sources:
             _sources = [e for e in _sources if 'type' in e.attrib]
         elif ('src' in xml.attrib) and ('type' in xml.attrib):
-                s = ET.Element('source', type=xml.attrib['type'])
-                s.text = xml.attrib['src']
-                _sources = [s]
-                del s
+            s = ET.Element('source', type=xml.attrib['type'])
+            s.text = xml.attrib['src']
+            _sources = [s]
+            del s
 
         if not _sources:
             raise Exception('Overlay "' + self.name + '" is missing a "source" entry!')
@@ -130,7 +130,7 @@ class Overlay(object):
             _location = ensure_unicode(source_elem.text.strip())
             return _class(self, xml, config, _location, ignore, quiet)
 
-        self.sources = map(create_overlay_source, _sources)
+        self.sources = [create_overlay_source(e) for e in _sources]
 
 
         _owner = xml.find('owner')
@@ -168,7 +168,7 @@ class Overlay(object):
             self.description = ''
             if not ignore:
                 raise Exception('Overlay "' + self.name + '" is missing a '
-	                                '"description" entry!')
+                        '"description" entry!')
             elif ignore == 1:
                 OUT.warn('Overlay "' + self.name + '" is missing a '
                          '"description" entry!', 4)
@@ -356,7 +356,7 @@ class Overlay(object):
         if self.feeds:
             result += u'\n%s:' % ((len(self.feeds) == 1) and "Feed" or "Feeds")
             for i in self.feeds:
-               result += u'\n  %s' % i
+                result += u'\n  %s' % i
             result += u'\n'
 
         return self._encode(result)
@@ -435,5 +435,5 @@ class Overlay(object):
 #--------------------------------------------------------------------------------
 
 if __name__ == '__main__':
-    import doctest, sys
+    import doctest
     doctest.testmod(sys.modules[__name__])
